# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireJobReqUserIDType(object):
    pass


@attr.s
class GetHireJobReq(object):
    user_id_type: GetHireJobReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, `people_admin_id`：以people_admin_id来识别用户, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    job_id: int = attr.ib(
        default=0, metadata={"req_type": "path"}
    )  # 职位 ID，请求Path中, 示例值：6001


@attr.s
class GetHireJobRespJobCustomizedDataValueTimeRange(object):
    start_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 开始时间
    end_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 结束时间


@attr.s
class GetHireJobRespJobCustomizedDataValueOptionName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文


@attr.s
class GetHireJobRespJobCustomizedDataValueOption(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项 ID
    name: GetHireJobRespJobCustomizedDataValueOptionName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 选项名称


@attr.s
class GetHireJobRespJobCustomizedDataValueOptionName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文


@attr.s
class GetHireJobRespJobCustomizedDataValueOption(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项 ID
    name: GetHireJobRespJobCustomizedDataValueOptionName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 选项名称


@attr.s
class GetHireJobRespJobCustomizedDataValue(object):
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 当字段类型为单行文本、多行文本、模块、默认字段时，从此字段取值
    option: GetHireJobRespJobCustomizedDataValueOption = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 当字段类型为单选时，从此字段取值
    option_list: typing.List[GetHireJobRespJobCustomizedDataValueOption] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 当字段类型为多选时，从此字段取值
    time_range: GetHireJobRespJobCustomizedDataValueTimeRange = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 当字段类型为时间段时，从此字段取值
    time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 当字段类型为日期选择、月份选择、年份选择时，从此字段取值，该字段是毫秒级时间戳
    number: str = attr.ib(default="", metadata={"req_type": "json"})  # 当字段类型为数字时，从此字段取值


@attr.s
class GetHireJobRespJobCustomizedDataName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文


@attr.s
class GetHireJobRespJobCustomizedData(object):
    object_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段 ID
    name: GetHireJobRespJobCustomizedDataName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字段名称
    object_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 字段类型, 可选值有: `1`：单行文本, `2`：多行文本, `3`：单选, `4`：多选, `5`：日期, `6`：月份选择, `7`：年份选择, `8`：时间段, `9`：数字, `10`：默认字段, `11`：模块
    value: GetHireJobRespJobCustomizedDataValue = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 自定义字段值


@attr.s
class GetHireJobRespJobJobType(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位类别 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位类别中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位类别英文名称


@attr.s
class GetHireJobRespJobJobCategory(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位序列 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位序列中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位序列英文名称
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 职位序列启用状态, 可选值有: `1`：启用, `2`：未启用


@attr.s
class GetHireJobRespJobHighlight(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位亮点 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位亮点中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位亮点英文名称


@attr.s
class GetHireJobRespJobMaxJobLevel(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级英文名称
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 职级启用状态, 可选值有: `1`：启用, `2`：未启用


@attr.s
class GetHireJobRespJobMinJobLevel(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 职级英文名称
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 职级启用状态, 可选值有: `1`：启用, `2`：未启用


@attr.s
class GetHireJobRespJobCity(object):
    city_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作地点城市代码
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作地点中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 工作地点英文名称


@attr.s
class GetHireJobRespJobDepartment(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门英文名称


@attr.s
class GetHireJobRespJobRecruitmentType(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 雇佣类型 ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 雇佣类型中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 雇佣类型英文名称
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 雇佣类型启用状态, 可选值有: `1`：启用, `2`：未启用


@attr.s
class GetHireJobRespJob(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位 ID
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位描述
    requirement: str = attr.ib(default="", metadata={"req_type": "json"})  # 职位要求
    recruitment_type: GetHireJobRespJobRecruitmentType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 雇佣类型
    department: GetHireJobRespJobDepartment = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 部门
    city: GetHireJobRespJobCity = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作地点
    min_job_level: GetHireJobRespJobMinJobLevel = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 最低职级
    max_job_level: GetHireJobRespJobMaxJobLevel = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 最高职级
    highlight_list: typing.List[GetHireJobRespJobHighlight] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 职位亮点
    job_category: GetHireJobRespJobJobCategory = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职位序列
    job_type: GetHireJobRespJobJobType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职位类别
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 启用状态, 可选值有: `1`：启用, `2`：未启用
    create_user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建人ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    process_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 职位流程类型, 可选值有: `1`：社招流程, `2`：校招流程
    customized_data_list: typing.List[GetHireJobRespJobCustomizedData] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段列表


@attr.s
class GetHireJobResp(object):
    job: GetHireJobRespJob = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 职位数据


def _gen_get_hire_job_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireJobResp,
        scope="Hire",
        api="GetHireJob",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/jobs/:job_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateSheetFilterViewConditionReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"
    filter_view_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 筛选视图 id, 示例值："pH9hbVcCXA"
    condition_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 设置筛选条件的列，使用字母号, 示例值："E"
    filter_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 筛选类型, 示例值："number"
    compare_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 比较类型, 示例值："less"
    expected: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 筛选参数, 示例值：6


@attr.s
class CreateSheetFilterViewConditionRespCondition(object):
    condition_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 设置筛选条件的列，使用字母号
    filter_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选类型
    compare_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 比较类型
    expected: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 筛选参数


@attr.s
class CreateSheetFilterViewConditionResp(object):
    condition: CreateSheetFilterViewConditionRespCondition = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 创建的筛选条件


def _gen_create_sheet_filter_view_condition_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateSheetFilterViewConditionResp,
        scope="Drive",
        api="CreateSheetFilterViewCondition",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/filter_views/:filter_view_id/conditions",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHelpdeskAgentScheduleReqAgentScheduleSchedule(object):
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开始时间, format 00:00 - 23:59, 示例值："00:00"
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 结束时间, format 00:00 - 23:59, 示例值："24:00"
    weekday: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 星期几, 1 - Monday, 2 - Tuesday, 3 - Wednesday, 4 - Thursday, 5 - Friday, 6 - Saturday, 7 - Sunday, 9 - Everday, 10 - Weekday, 11 - Weekend, 示例值：9


@attr.s
class UpdateHelpdeskAgentScheduleReqAgentSchedule(object):
    schedule: UpdateHelpdeskAgentScheduleReqAgentScheduleSchedule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作日程列表
    agent_skill_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服技能 ids


@attr.s
class UpdateHelpdeskAgentScheduleReq(object):
    agent_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 客服 id, 示例值："123456"
    agent_schedule: UpdateHelpdeskAgentScheduleReqAgentSchedule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作日程列表


@attr.s
class UpdateHelpdeskAgentScheduleResp(object):
    pass


def _gen_update_helpdesk_agent_schedule_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHelpdeskAgentScheduleResp,
        scope="Helpdesk",
        api="UpdateHelpdeskAgentSchedule",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agents/:agent_id/schedules",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetOKRReqUserIDType(object):
    pass


@attr.s
class BatchGetOKRReq(object):
    user_id_type: BatchGetOKRReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    okr_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # OKR ID 列表，最多10个
    lang: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 请求OKR的语言版本（比如@的人名），lang=en_us/zh_cn，请求 Query中, 示例值："zh_cn", 默认值: `zh_cn`


@attr.s
class BatchGetOKRRespOKRObjectiveAligningObjectiveOwner(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id


@attr.s
class BatchGetOKRRespOKRObjectiveAligningObjective(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # Objective的ID
    okr_id: str = attr.ib(default="", metadata={"req_type": "json"})  # OKR的ID
    owner: BatchGetOKRRespOKRObjectiveAligningObjectiveOwner = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 该Objective的Owner


@attr.s
class BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner(object):
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id


@attr.s
class BatchGetOKRRespOKRObjectiveAlignedObjective(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # Objective的ID
    okr_id: str = attr.ib(default="", metadata={"req_type": "json"})  # OKR的ID
    owner: BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 该Objective的Owner


@attr.s
class BatchGetOKRRespOKRObjectiveKrProgressRate(object):
    percent: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # Objective 进度百分比 >= 0
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # Objective 进度状态, 可选值有: `-1`：未更新, `0`：正常, `1`：有风险, `2`：已延期


@attr.s
class BatchGetOKRRespOKRObjectiveKrKrWeight(object):
    pass


@attr.s
class BatchGetOKRRespOKRObjectiveKr(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # Key Result ID
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # KeyResult 内容
    score: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # KeyResult打分（0 - 100）
    weight: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # KeyResult权重（0 - 100）（废弃）
    kr_weight: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # KeyResult的权重（0 - 100）
    progress_rate: BatchGetOKRRespOKRObjectiveKrProgressRate = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # KR进度


@attr.s
class BatchGetOKRRespOKRObjectiveProgressRate(object):
    percent: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # Objective 进度百分比 >= 0
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # Objective 进度状态, 可选值有: `-1`：未更新, `0`：正常, `1`：有风险, `2`：已延期


@attr.s
class BatchGetOKRRespOKRObjectiveWeight(object):
    pass


@attr.s
class BatchGetOKRRespOKRObjective(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # Objective ID
    permission: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 权限, 可选值有: `0`：此时OKR只返回id, `1`：返回OKR的其他具体字段
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # Objective 内容
    progress_report: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # Objective 进度记录内容
    score: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # Objective 分数（0 - 100）
    weight: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # Objective的权重（0 - 100）
    progress_rate: BatchGetOKRRespOKRObjectiveProgressRate = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # Objective进度
    kr_list: typing.List[BatchGetOKRRespOKRObjectiveKr] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # Objective KeyResult 列表
    aligned_objective_list: typing.List[
        BatchGetOKRRespOKRObjectiveAlignedObjective
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 对齐到该Objective的Objective列表
    aligning_objective_list: typing.List[
        BatchGetOKRRespOKRObjectiveAligningObjective
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 该Objective对齐到的Objective列表


@attr.s
class BatchGetOKRRespOKR(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # id
    permission: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # OKR的访问权限, 可选值有: `0`：此时OKR只返回id, `1`：返回OKR的其他具体字段
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    objective_list: typing.List[BatchGetOKRRespOKRObjective] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # Objective列表


@attr.s
class BatchGetOKRResp(object):
    okr_list: typing.List[BatchGetOKRRespOKR] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # OKR 列表


def _gen_batch_get_okr_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetOKRResp,
        scope="OKR",
        api="BatchGetOKR",
        method="GET",
        url="https://open.feishu.cn/open-apis/okr/v1/okrs/batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateDrivePublicPermissionReq(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 权限客体类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：电子表格, `file`：云空间文件, `wiki`：知识库节点（暂不支持）, `bitable`：多维表格, `docx`：文档
    token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 权限客体token, 示例值："doccnBKgoMyY5OMbUG6FioTXuBe"
    external_access: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否允许分享到租户外开关, 示例值：true
    security_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可创建副本/打印/导出/复制设置, 示例值："anyone_can_view", 可选值有: `anyone_can_view`：所有可访问此文档的用户, `anyone_can_edit`：有编辑权限的用户
    comment_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可评论设置, 示例值："anyone_can_view", 可选值有: `anyone_can_view`：所有可访问此文档的用户, `anyone_can_edit`：有编辑权限的用户
    share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 谁可以添加和管理协作者, 示例值："anyone", 可选值有: `anyone`：所有可阅读或编辑此文档的用户, `same_tenant`：组织内所有可阅读或编辑此文档的用户, `only_full_access`：只有所有权限者可以
    link_share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 链接共享, 示例值："tenant_readable", 可选值有: `tenant_readable`：组织内获得链接的人可阅读, `tenant_editable`：组织内获得链接的人可编辑, `anyone_readable`：获得链接的任何人可阅读（仅external_access=“true”时有效）, `anyone_editable`：获得链接的任何人可编辑（仅external_access=“true”时有效）, `closed`：关闭链接分享
    invite_external: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 非所有权限者/所有者是否允许邀请外部人, 示例值：true


@attr.s
class UpdateDrivePublicPermissionRespPermissionPublic(object):
    external_access: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否允许分享到租户外开关
    security_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可创建副本/打印/导出/复制设置, 可选值有: `anyone_can_view`：所有可访问此文档的用户, `anyone_can_edit`：有编辑权限的用户
    comment_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可评论设置, 可选值有: `anyone_can_view`：所有可访问此文档的用户, `anyone_can_edit`：有编辑权限的用户
    share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 谁可以添加和管理协作者, 可选值有: `anyone`：所有可阅读或编辑此文档的用户, `same_tenant`：组织内所有可阅读或编辑此文档的用户, `only_full_access`：只有所有权限者可以
    link_share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 链接共享, 可选值有: `tenant_readable`：组织内获得链接的人可阅读, `tenant_editable`：组织内获得链接的人可编辑, `anyone_readable`：获得链接的任何人可阅读（仅external_access=“true”时有效）, `anyone_editable`：获得链接的任何人可编辑（仅external_access=“true”时有效）, `closed`：关闭链接分享
    invite_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 非所有权限者/所有者是否允许邀请外部人


@attr.s
class UpdateDrivePublicPermissionResp(object):
    permission_public: UpdateDrivePublicPermissionRespPermissionPublic = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 本次更新后的文档公共设置


def _gen_update_drive_public_permission_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateDrivePublicPermissionResp,
        scope="Drive",
        api="UpdateDrivePublicPermission",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/drive/v1/permissions/:token/public",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateCalendarTimeoffEventReqUserIDType(object):
    pass


@attr.s
class CreateCalendarTimeoffEventReq(object):
    user_id_type: CreateCalendarTimeoffEventReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户id, 示例值："ou_XXXXXXXXXX"
    timezone: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 时区, 示例值："Asia/Shanghai"
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 休假开始时间: 有时间戳(1609430400)和日期(2021-01-01)两种格式，其它格式无效；,时间戳格式是按小时休假日程，日期格式是全天休假日程；,start_time与end_time格式需保持一致，否则无效。, 示例值："2021-01-01"
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 休假结束时间：,有时间戳(1609430400)和日期(2021-01-01)两种格式，其它格式无效；,时间戳格式是按小时休假日程，日期格式是全天休假日程；,start_time与end_time格式需保持一致，否则无效。, 示例值："2021-01-01"
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义请假日程标题，没有设置则为默认日程标题, 示例值："请假中(全天) / 1-Day Time Off"
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义请假日程描述，没有设置则为默认日程描述, 示例值："若删除此日程，飞书中相应的“请假”标签将自动消失，而请假系统中的休假申请不会被撤销。"


@attr.s
class CreateCalendarTimeoffEventResp(object):
    timeoff_event_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 请假日程ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户id
    timezone: str = attr.ib(default="", metadata={"req_type": "json"})  # 时区
    start_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 休假开始时间: 有时间戳(1609430400)和日期(2021-01-01)两种格式，其它格式无效；,时间戳格式是按小时休假日程，日期格式是全天休假日程；,start_time与end_time格式需保持一致，否则无效。
    end_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 休假结束时间：,有时间戳(1609430400)和日期(2021-01-01)两种格式，其它格式无效；,时间戳格式是按小时休假日程，日期格式是全天休假日程；,start_time与end_time格式需保持一致，否则无效。
    title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义请假日程标题，没有设置则为默认日程标题
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义请假日程描述，没有设置则为默认日程描述


def _gen_create_calendar_timeoff_event_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateCalendarTimeoffEventResp,
        scope="Calendar",
        api="CreateCalendarTimeoffEvent",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/timeoff_events",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskTicketCustomizedFieldListReq(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："6948728206392295444"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10；默认为20, 最大值：`100`
    visible: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否可见, 示例值：true


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildrenChildren(
    object
):
    pass


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildren(object):
    tag: str = attr.ib(default="", metadata={"req_type": "json"})  # 选项ID
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 展示名称
    children: typing.List[
        GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildrenChildren
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 同上：选项列表，只适用于多层下拉列表（最多可以设置三级下拉列表）


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptions(object):
    children: GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildren = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 选项列表


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItemUpdatedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItemCreatedBy(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    email: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户邮箱


@attr.s
class GetHelpdeskTicketCustomizedFieldListRespItem(object):
    ticket_customized_field_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 工单自定义字段ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    key_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 键名
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    position: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字段在列表后台管理列表中的位置
    field_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 类型
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 描述
    visible: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可见
    editable: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否可以修改
    required: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否必填
    created_at: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建时间
    updated_at: str = attr.ib(default="", metadata={"req_type": "json"})  # 更新时间
    created_by: GetHelpdeskTicketCustomizedFieldListRespItemCreatedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 创建用户
    updated_by: GetHelpdeskTicketCustomizedFieldListRespItemUpdatedBy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 更新用户
    dropdown_options: GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptions = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 下拉列表选项
    dropdown_allow_multiple: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否支持多选，仅在字段类型是dropdown的时候有效


@attr.s
class GetHelpdeskTicketCustomizedFieldListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    next_page_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 下一分页标识
    items: typing.List[GetHelpdeskTicketCustomizedFieldListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 工单自定义字段列表


def _gen_get_helpdesk_ticket_customized_field_list_req(
    request, options
) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskTicketCustomizedFieldListResp,
        scope="Helpdesk",
        api="GetHelpdeskTicketCustomizedFieldList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_customized_fields",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAccessTokenReq(object):
    grant_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 在本流程中，此值为 authorization_code
    code: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 来自[请求身份验证(新)](https://open.feishu.cn/document/ukTMukTMukTM/ukzN4UjL5cDO14SO3gTN)流程，用户扫码登录后会自动302到redirect_uri并带上此参数


@attr.s
class GetAccessTokenResp(object):
    access_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # user_access_token，用于获取用户资源
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像
    avatar_thumb: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像 72x72
    avatar_middle: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户头像 240x240
    avatar_big: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像 640x640
    expires_in: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # access_token 的有效期，单位: 秒
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户姓名
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户英文名称
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户在应用内的唯一标识
    union_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户统一ID
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 申请了"获取用户邮箱"权限的应用返回该字段
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 申请了"获取用户 user_id"权限的应用返回该字段
    mobile: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 申请了"获取用户手机号"权限的应用返回该字段
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 当前企业标识
    refresh_expires_in: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # refresh_token 的有效期，单位: 秒
    refresh_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 刷新用户 access_token 时使用的 token
    token_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 此处为 Bearer


def _gen_get_access_token_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAccessTokenResp,
        scope="Auth",
        api="GetAccessToken",
        method="POST",
        url="https://open.feishu.cn/open-apis/authen/v1/access_token",
        body=request,
        method_option=_new_method_option(options),
        need_app_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireAttachmentReq(object):
    attachment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 附件id, 示例值："6435242341238"


@attr.s
class GetHireAttachmentRespAttachment(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 附件id
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 附件的url
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 附件文件名
    mime: str = attr.ib(default="", metadata={"req_type": "json"})  # 媒体类型/MIME
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 附件创建时间（单位ms）


@attr.s
class GetHireAttachmentResp(object):
    attachment: GetHireAttachmentRespAttachment = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 附件信息


def _gen_get_hire_attachment_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireAttachmentResp,
        scope="Hire",
        api="GetHireAttachment",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/attachments/:attachment_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApprovalReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 Code
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # zh-CN - 中文<br>en-US - 英文  <br>ja-JP - 日文


@attr.s
class GetApprovalRespViewer(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可见人类型，分别有：<br>TENANT：租户内可见<br>DEPARTMENT：指定部门<br> USER：指定用户<br>NONE：任何人都不可见
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 在可见人类型为DEPARTMENT时，open_id为部门的open_id<br>在可见人类型为USER时，open_id为用户的open_id
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 在可见人类型为USER时，表示可见人用户id


@attr.s
class GetApprovalRespNode(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 节点名称
    need_approver: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否发起人自选节点<br>true - 发起审批时需要提交审批人
    node_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 节点 ID
    custom_node_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 节点自定义 ID，如果没有设置则不返回
    node_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批方式<br>AND -会签<br>OR - 或签


@attr.s
class GetApprovalRespForm(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件 ID
    custom_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件自定义 ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件名称
    type: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件类型


@attr.s
class GetApprovalResp(object):
    approval_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批名称
    form: GetApprovalRespForm = attr.ib(
        factory=lambda: GetApprovalRespForm(), metadata={"req_type": "json"}
    )  # json 数组，**控件信息**
    node_list: typing.List[GetApprovalRespNode] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 节点信息
    viewers: typing.List[GetApprovalRespViewer] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 可见人列表


def _gen_get_approval_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApprovalResp,
        scope="Approval",
        api="GetApproval",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/approval/get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSheetConditionFormatReqSheetCfIDs(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet的id
    cf_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 条件格式id


@attr.s
class DeleteSheetConditionFormatReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # sheet 的 token，获取方式见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    sheet_cf_ids: DeleteSheetConditionFormatReqSheetCfIDs = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 表格条件格式id


@attr.s
class DeleteSheetConditionFormatRespResponse(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet的Id
    cf_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 条件格式id
    res_code: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 条件格式删除状态码，0表示成功，非0表示失败
    res_msg: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 条件格式删除返回的状态信息，空表示成功，非空表示失败原因


@attr.s
class DeleteSheetConditionFormatResp(object):
    responses: typing.List[DeleteSheetConditionFormatRespResponse] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 响应


def _gen_delete_sheet_condition_format_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSheetConditionFormatResp,
        scope="Drive",
        api="DeleteSheetConditionFormat",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/condition_formats/batch_delete",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentSkillRuleListReq(object):
    pass


@attr.s
class GetHelpdeskAgentSkillRuleListRespRule(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # rule id, 看[获取客服技能rules](https://open.feishu.cn/document/ukTMukTMukTM/ucDOyYjL3gjM24yN4IjN/list-agent-skill-rules) 用于获取rules options
    operator_options: typing.List[int] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # rule操作数value，[客服技能及运算符](https://open.feishu.cn/document/ukTMukTMukTM/ucDOyYjL3gjM24yN4IjN/operator-options)
    operand: str = attr.ib(default="", metadata={"req_type": "json"})  # rule操作数value
    category: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # rule type，1-知识库，2-工单信息，3-用户飞书信息
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # rule 名


@attr.s
class GetHelpdeskAgentSkillRuleListResp(object):
    rules: typing.List[GetHelpdeskAgentSkillRuleListRespRule] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # rules列表


def _gen_get_helpdesk_agent_skill_rule_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentSkillRuleListResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentSkillRuleList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skill_rules",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateChatAnnouncementReq(object):
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待修改公告的群 ID, 示例值："oc_5ad11d72b830411d72b836c20"
    revision: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档当前版本号 int64 类型，get 接口会返回, 示例值："12"
    requests: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 修改文档请求的序列化字段


@attr.s
class UpdateChatAnnouncementResp(object):
    pass


def _gen_update_chat_announcement_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateChatAnnouncementResp,
        scope="Chat",
        api="UpdateChatAnnouncement",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/im/v1/chats/:chat_id/announcement",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetTenantReq(object):
    pass


@attr.s
class GetTenantRespTenantAvatar(object):
    avatar_origin: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业头像
    avatar_72: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业头像 72x72
    avatar_240: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业头像 240x240
    avatar_640: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业头像 640x640


@attr.s
class GetTenantRespTenant(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业名称
    display_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业编号
    tenant_tag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 个人版/团队版标志, 可选值有: `0`：团队版, `2`：个人版
    tenant_key: str = attr.ib(default="", metadata={"req_type": "json"})  # 企业标识
    avatar: GetTenantRespTenantAvatar = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 企业头像


@attr.s
class GetTenantResp(object):
    tenant: GetTenantRespTenant = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 企业信息


def _gen_get_tenant_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetTenantResp,
        scope="Tenant",
        api="GetTenant",
        method="GET",
        url="https://open.feishu.cn/open-apis/tenant/v2/tenant/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateDriveCommentPatchReqFileType(object):
    pass


@attr.s
class UpdateDriveCommentPatchReq(object):
    file_type: UpdateDriveCommentPatchReqFileType = attr.ib(
        factory=lambda: UpdateDriveCommentPatchReqFileType(),
        metadata={"req_type": "query"},
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnGp4UK1UskrOEJwBXd3****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 评论ID, 示例值："6916106822734578184"
    is_solved: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 评论解决标志, 示例值：true


@attr.s
class UpdateDriveCommentPatchResp(object):
    pass


def _gen_update_drive_comment_patch_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateDriveCommentPatchResp,
        scope="Drive",
        api="UpdateDriveCommentPatch",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments/:comment_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireEmployeeByApplicationReq(object):
    application_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 投递ID, 示例值："123"


@attr.s
class GetHireEmployeeByApplicationRespEmployee(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工ID
    application_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递ID
    onboard_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 入职状态, 可选值有: `1`：已入职, `2`：已离职
    conversion_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 转正状态, 可选值有: `1`：未转正, `2`：已转正
    onboard_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 实际入职时间
    expected_conversion_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 预期转正时间
    actual_conversion_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际转正时间
    overboard_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 离职时间
    overboard_note: str = attr.ib(default="", metadata={"req_type": "json"})  # 离职原因


@attr.s
class GetHireEmployeeByApplicationResp(object):
    employee: GetHireEmployeeByApplicationRespEmployee = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 员工信息


def _gen_get_hire_employee_by_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireEmployeeByApplicationResp,
        scope="Hire",
        api="GetHireEmployeeByApplication",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/employees/get_by_application",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskTicketCustomizedFieldReq(object):
    ticket_customized_field_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 工单自定义字段ID, 示例值："6948728206392295444"


@attr.s
class DeleteHelpdeskTicketCustomizedFieldResp(object):
    pass


def _gen_delete_helpdesk_ticket_customized_field_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskTicketCustomizedFieldResp,
        scope="Helpdesk",
        api="DeleteHelpdeskTicketCustomizedField",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_customized_fields/:ticket_customized_field_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetMeetingRoomFreebusyReq(object):
    room_ids: str = attr.ib(default="", metadata={"req_type": "query"})  # 用于查询指定会议室的 ID
    time_min: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 查询会议室忙闲的起始时间，需要遵循格式 [RFC3339](https://tools.ietf.org/html/rfc3339)，需要进行URL Encode
    time_max: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 查询会议室忙闲的结束时间，需要遵循格式 [RFC3339](https://tools.ietf.org/html/rfc3339)，需要进行URL Encode


@attr.s
class BatchGetMeetingRoomFreebusyRespFreeBusyRoomIDOrganizerInfo(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 组织者姓名
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 组织者 open_id


@attr.s
class BatchGetMeetingRoomFreebusyRespFreeBusyRoomID(object):
    start_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 忙碌起始时间
    end_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 忙碌结束时间
    uid: str = attr.ib(default="", metadata={"req_type": "json"})  # 日程 ID
    original_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 日程实例的原始时间, 非重复日程为0，重复日程为非0
    organizer_info: BatchGetMeetingRoomFreebusyRespFreeBusyRoomIDOrganizerInfo = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 组织者信息, 私密日程不返回该信息


@attr.s
class BatchGetMeetingRoomFreebusyRespFreeBusy(object):
    room_id: BatchGetMeetingRoomFreebusyRespFreeBusyRoomID = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 与请求合法参数相同，表示之后是对应会议室的忙闲状态


@attr.s
class BatchGetMeetingRoomFreebusyResp(object):
    time_min: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询会议室忙闲的起始时间，与请求参数完全相同
    time_max: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询会议室忙闲的结束时间，与请求参数完全相同
    free_busy: BatchGetMeetingRoomFreebusyRespFreeBusy = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议室忙闲列表


def _gen_batch_get_meeting_room_freebusy_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetMeetingRoomFreebusyResp,
        scope="MeetingRoom",
        api="BatchGetMeetingRoomFreebusy",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/freebusy/batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveMemberPermissionOldReqMembers(object):
    member_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户类型，可选 **email 、openid、openchat、userid**
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型下的值
    perm: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要增加的权限，权限值："view"，"edit"


@attr.s
class CreateDriveMemberPermissionOldReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型  "doc" 、"sheet" 、 "bitable" or "file"
    members: CreateDriveMemberPermissionOldReqMembers = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户
    notify_lark: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 添加权限后是否飞书/lark通知对方<br>true 通知 or false 不通知


@attr.s
class CreateDriveMemberPermissionOldRespFailMembers(object):
    member_type: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型
    member_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户类型下的值
    perm: str = attr.ib(default="", metadata={"req_type": "json"})  # 需要增加的权限


@attr.s
class CreateDriveMemberPermissionOldResp(object):
    is_all_success: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否全部成功
    fail_members: CreateDriveMemberPermissionOldRespFailMembers = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 添加权限失败的用户信息


def _gen_create_drive_member_permission_old_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveMemberPermissionOldResp,
        scope="Drive",
        api="CreateDriveMemberPermissionOld",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/member/create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UploadDriveFileReqFile(object):
    pass


@attr.s
class UploadDriveFileReq(object):
    file_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件名, 示例值："test.txt", 最大长度：`250` 字符
    parent_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 上传点类型, 示例值："explorer", 可选值有: `explorer`：云空间
    parent_node: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件夹token, 示例值："fldcn77hdDT5"
    size: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件大小,全量上传最大20M, 示例值：1024, 最大值：`20971520`
    checksum: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件adler32校验和, 示例值："123423882374238957235"
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件数据, 示例值：file binary


@attr.s
class UploadDriveFileResp(object):
    file_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文件的 token


def _gen_upload_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UploadDriveFileResp,
        scope="Drive",
        api="UploadDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/files/upload_all",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
        is_file=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetTaskReminderListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：50, 最大值：`50`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："「填写上次返回的page_token」"
    task_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 任务 ID, 示例值："0d38e26e-190a-49e9-93a2-35067763ed1f"


@attr.s
class GetTaskReminderListRespItem(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 提醒时间设置的 ID（在删除时候需要使用这个）
    relative_fire_minute: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 相对于截止时间的提醒时间（如提前 30 分钟，截止时间后 30 分钟，则为 -30）


@attr.s
class GetTaskReminderListResp(object):
    items: typing.List[GetTaskReminderListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 返回提醒时间设置列表
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项


def _gen_get_task_reminder_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetTaskReminderListResp,
        scope="Task",
        api="GetTaskReminderList",
        method="GET",
        url="https://open.feishu.cn/open-apis/task/v1/tasks/:task_id/reminders",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireOfferByApplicationReqUserIDType(object):
    pass


@attr.s
class GetHireOfferByApplicationReq(object):
    user_id_type: GetHireOfferByApplicationReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    application_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 投递ID, 示例值："12312312312"


@attr.s
class GetHireOfferByApplicationRespOfferSalaryPlanCustomizeInfo(object):
    object_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID
    customize_value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段Value


@attr.s
class GetHireOfferByApplicationRespOfferSalaryPlan(object):
    currency: str = attr.ib(default="", metadata={"req_type": "json"})  # 币种
    basic_salary: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 基本薪资, 注意是json
    probation_salary_percentage: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 试用期百分比
    award_salary_multiple: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 年终奖月数
    option_shares: str = attr.ib(default="", metadata={"req_type": "json"})  # 期权股数
    quarterly_bonus: str = attr.ib(default="", metadata={"req_type": "json"})  # 季度奖金额
    half_year_bonus: str = attr.ib(default="", metadata={"req_type": "json"})  # 半年奖金额
    total_annual_cash: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 年度现金总额(数量，非公式)
    customize_info_list: typing.List[
        GetHireOfferByApplicationRespOfferSalaryPlanCustomizeInfo
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段的value信息


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoCustomizeInfo(object):
    object_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义字段ID
    customize_value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 自定义字段Value


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCountry(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoWorkAddressState(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCity(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoWorkAddressDistrict(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoWorkAddress(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    district: GetHireOfferByApplicationRespOfferBasicInfoWorkAddressDistrict = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 区域信息
    city: GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCity = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 城市信息
    state: GetHireOfferByApplicationRespOfferBasicInfoWorkAddressState = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 省信息
    country: GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCountry = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国家信息


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCountry(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressState(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCity(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,, 可选值有: `1`：COUNTRY, `2`：STATE, `3`：CITY, `4`：DISTRICT, `5`：ADDRESS


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressDistrict(object):
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编码
    location_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 地址类型 1=COUNTRY, 2=STATE, 3=CITY, 4=DISTRICT, 5=ADDRESS,


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoOnboardAddress(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称
    district: GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressDistrict = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 区域信息
    city: GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCity = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 城市信息
    state: GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressState = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 省信息
    country: GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCountry = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国家信息


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoLevel(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoSequence(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfoRecruitmentType(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名称
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名称


@attr.s
class GetHireOfferByApplicationRespOfferBasicInfo(object):
    offer_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # Offer类型 1=Social, 2=Campus, 3=Intern, 4=InternTransfer, 可选值有: `1`：Social, `2`：Campus, `3`：Intern, `4`：InternTransfer
    remark: str = attr.ib(default="", metadata={"req_type": "json"})  # 备注
    expire_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # Offer过期时间
    owner_user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # string
    leader_user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # string
    onboard_date: str = attr.ib(default="", metadata={"req_type": "json"})  # 入职日期
    department_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 入职部门
    probation_month: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 试用期, 比如试用期6个月
    contract_year: int = attr.ib(default=0, metadata={"req_type": "json"})  # 合同期, 比如3年
    recruitment_type: GetHireOfferByApplicationRespOfferBasicInfoRecruitmentType = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 雇员类型
    sequence: GetHireOfferByApplicationRespOfferBasicInfoSequence = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 序列
    level: GetHireOfferByApplicationRespOfferBasicInfoLevel = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 级别
    onboard_address: GetHireOfferByApplicationRespOfferBasicInfoOnboardAddress = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 入职地点
    work_address: GetHireOfferByApplicationRespOfferBasicInfoWorkAddress = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 工作地点
    customize_info_list: typing.List[
        GetHireOfferByApplicationRespOfferBasicInfoCustomizeInfo
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 自定义字段的value信息


@attr.s
class GetHireOfferByApplicationRespOffer(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # Offer id
    application_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递id
    basic_info: GetHireOfferByApplicationRespOfferBasicInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 基础信息
    salary_plan: GetHireOfferByApplicationRespOfferSalaryPlan = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 薪酬计划
    schema_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 当前offer使用的schema
    offer_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # Offer状态, 可选值有: `0`：所有, `1`：未申请, `2`：审批中, `3`：审批已撤回, `4`：审批通过, `5`：审批不通过, `6`：Offer 已发出, `7`：候选人已接受, `8`：候选人已拒绝, `9`：Offer 已失效


@attr.s
class GetHireOfferByApplicationResp(object):
    offer: GetHireOfferByApplicationRespOffer = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # Offer数据


def _gen_get_hire_offer_by_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireOfferByApplicationResp,
        scope="Hire",
        api="GetHireOfferByApplication",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/applications/:application_id/offer",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateCalendarEventAttendeeReqAttendeeType(object):
    pass


@attr.s
class CreateCalendarEventAttendeeReqAttendee(object):
    type: CreateCalendarEventAttendeeReqAttendeeType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 参与人类型, 示例值："user", 可选值有: `user`：用户, `chat`：群组, `resource`：会议室, `third_party`：邮箱
    is_optional: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 参与人是否为「可选参加」，无法编辑群参与人的此字段, 示例值：true, 默认值: `false`
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人的用户id，依赖于user_id_type返回对应的取值，当is_external为true时，此字段只会返回open_id或者union_id, 示例值："ou_xxxxxxxx"
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # chat类型参与人的群组chat_id, 示例值："om_xxxxxxxxx"
    room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # resource类型参与人的会议室room_id, 示例值："omm_xxxxxxxx"
    third_party_email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # third_party类型参与人的邮箱, 示例值："wangwu@email.com"


@attr.s
class CreateCalendarEventAttendeeReqUserIDType(object):
    pass


@attr.s
class CreateCalendarEventAttendeeReq(object):
    user_id_type: CreateCalendarEventAttendeeReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历 ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    event_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日程 ID, 示例值："xxxxxxxxx_0"
    attendees: typing.List[CreateCalendarEventAttendeeReqAttendee] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 新增参与人列表
    need_notification: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否给参与人发送bot通知 默认为true, 示例值：false


@attr.s
class CreateCalendarEventAttendeeRespAttendeeChatMember(object):
    rsvp_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人RSVP状态, 可选值有: `needs_action`：参与人尚未回复状态，或表示会议室预约中, `accept`：参与人回复接受，或表示会议室预约成功, `tentative`：参与人回复待定, `decline`：参与人回复拒绝，或表示会议室预约失败, `removed`：参与人或会议室已经从日程中被移除
    is_optional: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为「可选参加」, 默认值: `false`
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人名称
    is_organizer: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为日程组织者
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为外部参与人


@attr.s
class CreateCalendarEventAttendeeRespAttendeeType(object):
    pass


@attr.s
class CreateCalendarEventAttendeeRespAttendee(object):
    type: CreateCalendarEventAttendeeRespAttendeeType = attr.ib(
        factory=lambda: CreateCalendarEventAttendeeRespAttendeeType(),
        metadata={"req_type": "json"},
    )  # 参与人类型, 可选值有: `user`：用户, `chat`：群组, `resource`：会议室, `third_party`：邮箱
    attendee_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人ID
    rsvp_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人RSVP状态, 可选值有: `needs_action`：参与人尚未回复状态，或表示会议室预约中, `accept`：参与人回复接受，或表示会议室预约成功, `tentative`：参与人回复待定, `decline`：参与人回复拒绝，或表示会议室预约失败, `removed`：参与人或会议室已经从日程中被移除
    is_optional: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为「可选参加」，无法编辑群参与人的此字段, 默认值: `false`
    is_organizer: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为日程组织者
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 参与人是否为外部参与人；外部参与人不支持编辑
    display_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 参与人名称
    chat_members: typing.List[
        CreateCalendarEventAttendeeRespAttendeeChatMember
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 群中的群成员，当type为Chat时有效；群成员不支持编辑
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 参与人的用户id，依赖于user_id_type返回对应的取值，当is_external为true时，此字段只会返回open_id或者union_id
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # chat类型参与人的群组chat_id
    room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # resource类型参与人的会议室room_id
    third_party_email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # third_party类型参与人的邮箱


@attr.s
class CreateCalendarEventAttendeeResp(object):
    attendees: typing.List[CreateCalendarEventAttendeeRespAttendee] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 新增参与人后的日程所有参与人列表


def _gen_create_calendar_event_attendee_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateCalendarEventAttendeeResp,
        scope="Calendar",
        api="CreateCalendarEventAttendee",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/events/:event_id/attendees",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DetectFaceAttributesReq(object):
    image: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 图片 base64 数据, 示例值："图片 base64 后的字符串"


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeRightEye(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeLeftEye(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeChin(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeMouth(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeCheek(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeNose(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOccludeEyebrow(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualityOcclude(object):
    eyebrow: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 眉毛被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    nose: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 鼻子被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    cheek: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 脸颊被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    mouth: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 嘴被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    chin: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 下巴被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    left_eye: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 左眼睛被遮挡情况：[0, 1] 值越大被遮挡的概率越高
    right_eye: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 右眼睛被遮挡情况：[0, 1] 值越大被遮挡的概率越高


@attr.s
class DetectFaceAttributesRespFaceInfoQualityBrightness(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQualitySharpness(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoQuality(object):
    sharpness: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 清晰度，值越高越清晰
    brightness: float = attr.ib(default=None, metadata={"req_type": "json"})  # 亮度
    occlude: DetectFaceAttributesRespFaceInfoQualityOcclude = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 面部遮挡属性


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeMaskProbability(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeMask(object):
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 属性
    probability: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 识别置信度，[0, 1]，代表判断正确的概率


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeGlassProbability(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeGlass(object):
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 属性
    probability: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 识别置信度，[0, 1]，代表判断正确的概率


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeHatProbability(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeHat(object):
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 属性
    probability: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 识别置信度，[0, 1]，代表判断正确的概率


@attr.s
class DetectFaceAttributesRespFaceInfoAttributePose(object):
    pitch: int = attr.ib(default=0, metadata={"req_type": "json"})  # 脸部上下偏移 [-90, 90]
    yaw: int = attr.ib(default=0, metadata={"req_type": "json"})  # 脸部左右偏移 [-90, 90]
    roll: int = attr.ib(default=0, metadata={"req_type": "json"})  # 平面旋转 [-90, 90]


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeEmotionProbability(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeEmotion(object):
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 属性
    probability: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 识别置信度，[0, 1]，代表判断正确的概率


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeGenderProbability(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoAttributeGender(object):
    type: int = attr.ib(default=0, metadata={"req_type": "json"})  # 属性
    probability: float = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 识别置信度，[0, 1]，代表判断正确的概率


@attr.s
class DetectFaceAttributesRespFaceInfoAttribute(object):
    gender: DetectFaceAttributesRespFaceInfoAttributeGender = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 性别信息：0 男性，1 女性
    age: int = attr.ib(default=0, metadata={"req_type": "json"})  # 年龄大小
    emotion: DetectFaceAttributesRespFaceInfoAttributeEmotion = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 情绪：0 自然, 1 高兴，2 惊讶，3 害怕，4 悲伤，5 生气, 6 厌恶
    beauty: int = attr.ib(default=0, metadata={"req_type": "json"})  # 颜值打分：[0, 100]
    pose: DetectFaceAttributesRespFaceInfoAttributePose = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸姿态
    hat: DetectFaceAttributesRespFaceInfoAttributeHat = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 帽子：0 未戴帽子，1 戴帽子
    glass: DetectFaceAttributesRespFaceInfoAttributeGlass = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 眼镜：0 未戴眼镜，1 戴眼镜
    mask: DetectFaceAttributesRespFaceInfoAttributeMask = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 口罩：0 未戴口罩，1 戴口罩


@attr.s
class DetectFaceAttributesRespFaceInfoPositionLowerRightY(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoPositionLowerRightX(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoPositionLowerRight(object):
    x: float = attr.ib(default=None, metadata={"req_type": "json"})  # 横轴坐标
    y: float = attr.ib(default=None, metadata={"req_type": "json"})  # 纵轴坐标


@attr.s
class DetectFaceAttributesRespFaceInfoPositionUpperLeftY(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoPositionUpperLeftX(object):
    pass


@attr.s
class DetectFaceAttributesRespFaceInfoPositionUpperLeft(object):
    x: float = attr.ib(default=None, metadata={"req_type": "json"})  # 横轴坐标
    y: float = attr.ib(default=None, metadata={"req_type": "json"})  # 纵轴坐标


@attr.s
class DetectFaceAttributesRespFaceInfoPosition(object):
    upper_left: DetectFaceAttributesRespFaceInfoPositionUpperLeft = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸框的左上角坐标
    lower_right: DetectFaceAttributesRespFaceInfoPositionLowerRight = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸框的右下角坐标


@attr.s
class DetectFaceAttributesRespFaceInfo(object):
    position: DetectFaceAttributesRespFaceInfoPosition = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸位置信息
    attribute: DetectFaceAttributesRespFaceInfoAttribute = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸属性信息
    quality: DetectFaceAttributesRespFaceInfoQuality = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 人脸质量信息


@attr.s
class DetectFaceAttributesRespImageInfo(object):
    width: int = attr.ib(default=0, metadata={"req_type": "json"})  # 图片的宽度
    height: int = attr.ib(default=0, metadata={"req_type": "json"})  # 图片的高度


@attr.s
class DetectFaceAttributesResp(object):
    image_info: DetectFaceAttributesRespImageInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 图片信息
    face_infos: typing.List[DetectFaceAttributesRespFaceInfo] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 人脸信息列表


def _gen_detect_face_attributes_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DetectFaceAttributesResp,
        scope="AI",
        api="DetectFaceAttributes",
        method="POST",
        url="https://open.feishu.cn/open-apis/face_detection/v1/image/detect_face_attributes",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetFilterViewReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 表格 token, 示例值："shtcnmBA*****yGehy8"
    sheet_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 子表 id, 示例值："0b**12"
    filter_view_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 筛选视图 id, 示例值："pH9hbVcCXA"
    filter_view_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 筛选视图名字, 示例值："筛选视图 1"
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 筛选视图的筛选范围, 示例值："0b**12!C1:H14"


@attr.s
class UpdateSheetFilterViewRespFilterView(object):
    filter_view_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图 id
    filter_view_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图名字
    range_: str = attr.ib(default="", metadata={"req_type": "json"})  # 筛选视图的筛选范围


@attr.s
class UpdateSheetFilterViewResp(object):
    filter_view: UpdateSheetFilterViewRespFilterView = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 更新后的筛选视图的 id 、name、range


def _gen_update_sheet_filter_view_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetFilterViewResp,
        scope="Drive",
        api="UpdateSheetFilterView",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/sheets/v3/spreadsheets/:spreadsheet_token/sheets/:sheet_id/filter_views/:filter_view_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateEmployeeTypeEnumReqI18nContent(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言, 示例值："zh_cn"
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # i18n内容, 示例值："专家"


@attr.s
class CreateEmployeeTypeEnumReq(object):
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举内容, 示例值："专家", 长度范围：`1` ～ `100` 字符
    enum_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 示例值：2, 可选值有: `1`：内置类型, `2`：自定义
    enum_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 示例值：1, 可选值有: `1`：激活, `2`：未激活
    i18n_content: CreateEmployeeTypeEnumReqI18nContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # i18n定义


@attr.s
class CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent(object):
    locale: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # i18n内容


@attr.s
class CreateEmployeeTypeEnumRespEmployeeTypeEnum(object):
    enum_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值id
    enum_value: str = attr.ib(default="", metadata={"req_type": "json"})  # 枚举值
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 枚举内容, 长度范围：`1` ～ `100` 字符
    enum_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：内置类型, `2`：自定义
    enum_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 类型, 可选值有: `1`：激活, `2`：未激活
    i18n_content: CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # i18n定义


@attr.s
class CreateEmployeeTypeEnumResp(object):
    employee_type_enum: CreateEmployeeTypeEnumRespEmployeeTypeEnum = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 新建的人员类型信息


def _gen_create_employee_type_enum_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateEmployeeTypeEnumResp,
        scope="Contact",
        api="CreateEmployeeTypeEnum",
        method="POST",
        url="https://open.feishu.cn/open-apis/contact/v3/employee_type_enums",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenSSOLoginReq(object):
    sso_domain: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户的域名，填写的是租户在admin后台配置的租户域名信息。当在admin后台改动租户的域名时，需要同步修改applink该参数值
    tenant_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户名，用于在切换租户时，客户端展示即将登录到的租户名称，一般填写公司名即可


@attr.s
class OpenSSOLoginResp(object):
    pass


def _gen_open_sso_login_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenSSOLoginResp,
        scope="AppLink",
        api="OpenSSOLogin",
        method="",
        url="https://applink.feishu.cn/client/passport/sso_login",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenWebURLReq(object):
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 指定需要在客户端内打开的具体链接，需要执行encodeURIComponent，4.2+版本支持lark协议
    mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打开的容器模式，枚举值包括：<br>`sidebar-semi` 在侧边栏打开；<br>`window` 在独立窗口打开
    height: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义独立窗口高度
    width: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义独立窗口宽度


@attr.s
class OpenWebURLResp(object):
    pass


def _gen_open_web_url_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenWebURLResp,
        scope="AppLink",
        api="OpenWebURL",
        method="",
        url="https://applink.feishu.cn/client/web_url/open",
        body=request,
        method_option=_new_method_option(options),
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_tenant_tenant_get import (
    GetTenantReq,
    GetTenantResp,
    _gen_get_tenant_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkTenantService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_tenant(
        self, request: GetTenantReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetTenantResp, Response]:
        return self.cli.raw_request(_gen_get_tenant_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GenerateCaldavConfReq(object):
    device_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要同步日历的设备名，在日历中展示用来管理密码, 示例值："iPhone", 最大长度：`100` 字符


@attr.s
class GenerateCaldavConfResp(object):
    password: str = attr.ib(default="", metadata={"req_type": "json"})  # caldav密码
    user_name: str = attr.ib(default="", metadata={"req_type": "json"})  # caldav用户名
    server_address: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务器地址
    device_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 设备名


def _gen_generate_caldav_conf_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GenerateCaldavConfResp,
        scope="Calendar",
        api="GenerateCaldavConf",
        method="POST",
        url="https://open.feishu.cn/open-apis/calendar/v4/settings/generate_caldav_conf",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireApplicationReq(object):
    application_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 投递ID, 示例值："212121"


@attr.s
class GetHireApplicationRespApplicationStage(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 阶段id
    zh_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 阶段中文名字
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 阶段类型, 可选值有: `1`：筛选型, `2`：评估型, `3`：笔试型, `4`：面试型, `5`：Offer型, `6`：待入职, `7`：已入职, `8`：其它类型, `255`：系统默认


@attr.s
class GetHireApplicationRespApplication(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递id
    job_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递的职位id
    talent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 候选人id
    resume_resource_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 简历来源id
    stage: GetHireApplicationRespApplicationStage = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 投递处于的阶段
    active_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 活跃状态, 可选值有: `1`：活跃, `2`：非活跃, `3`：全部


@attr.s
class GetHireApplicationResp(object):
    application: GetHireApplicationRespApplication = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 投递数据


def _gen_get_hire_application_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireApplicationResp,
        scope="Hire",
        api="GetHireApplication",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/applications/:application_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CopyDriveFileReq(object):
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 需要复制的源文件或文档的 token, 获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要创建文档的类型   "doc" 、"sheet" or "bitable"
    dst_folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标文件夹的 token, 获取方式见 [概述](https://open.feishu.cn/document/ukTMukTMukTM/uUDN04SN0QjL1QDN/files/guide/introduction)
    dst_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 复制的副本文件的新名称
    comment_needed: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否复制评论


@attr.s
class CopyDriveFileResp(object):
    folder_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标文件夹的 token
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 新创建文档的版本号
    token: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 token
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 新建文档的类型，"doc" or "sheet"
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 新创建文档的 url


def _gen_copy_drive_file_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CopyDriveFileResp,
        scope="Drive",
        api="CopyDriveFile",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/explorer/v2/file/copy/files/:fileToken",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DetectTextLanguageReq(object):
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 需要被识别语种的文本, 示例值："你好"


@attr.s
class DetectTextLanguageResp(object):
    language: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 识别的文本语种，返回符合 ISO 693-1 标准


def _gen_detect_text_language_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DetectTextLanguageResp,
        scope="AI",
        api="DetectTextLanguage",
        method="POST",
        url="https://open.feishu.cn/open-apis/translation/v1/text/detect",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetSheetValueReqUserIDType(object):
    pass


@attr.s
class BatchGetSheetValueReq(object):
    ranges: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 多个查询范围 如 url?ranges=range1,range2 ，⁣其中 range 包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    value_render_option: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # valueRenderOption=ToString 可返回纯文本的值；valueRenderOption=FormattedValue 计算并格式化单元格；valueRenderOption=Formula单元格中含有公式时返回公式本身；valueRenderOption=UnformattedValue计算但不对单元格进行格式化
    date_time_render_option: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # dateTimeRenderOption=FormattedString 计算并将时间日期按照其格式进行格式化，但不会对数字进行格式化，返回格式化后的字符串。
    user_id_type: BatchGetSheetValueReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 返回的用户id类型，可选open_id,union_id
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class BatchGetSheetValueRespValueRangeValue(object):
    pass


@attr.s
class BatchGetSheetValueRespValueRange(object):
    major_dimension: str = attr.ib(default="", metadata={"req_type": "json"})  # 插入维度
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 返回数据的范围，为空时表示查询范围没有数据
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的版本号
    values: typing.List[BatchGetSheetValueRespValueRangeValue] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 查询得到的值


@attr.s
class BatchGetSheetValueResp(object):
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的版本号
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token，详见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    total_cells: int = attr.ib(default=0, metadata={"req_type": "json"})  # 读取的单元格总数
    value_ranges: typing.List[BatchGetSheetValueRespValueRange] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 值与范围


def _gen_batch_get_sheet_value_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetSheetValueResp,
        scope="Drive",
        api="BatchGetSheetValue",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/values_batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateSheetDataValidationDropdownReqDataValidationOptions(object):
    multiple_values: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 单选填false, 多选填true，不填默认为false
    highlight_valid_data: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否设置颜色和胶囊样式, 不填默认为false
    colors: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 当highlightValidData为true时，color需填颜色,与conditionValues中的值一一对应。需是RGB16进制格式,如"#fffd00"


@attr.s
class CreateSheetDataValidationDropdownReqDataValidation(object):
    condition_values: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 下拉列表选项值, 需为字符串,不能包含","，选项值最长100字符,选项个数最多500个
    options: CreateSheetDataValidationDropdownReqDataValidationOptions = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可选属性


@attr.s
class CreateSheetDataValidationDropdownReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    range_: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    data_validation_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 下拉列表填"list"
    data_validation: CreateSheetDataValidationDropdownReqDataValidation = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 下拉列表规则属性


@attr.s
class CreateSheetDataValidationDropdownResp(object):
    pass


def _gen_create_sheet_data_validation_dropdown_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateSheetDataValidationDropdownResp,
        scope="Drive",
        api="CreateSheetDataValidationDropdown",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dataValidation",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceUserFlowReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceUserFlowReq(object):
    employee_type: GetAttendanceUserFlowReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceUserFlowReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 请求体中的 user_id 和 creator_id 的员工工号类型，可用值：【employee_id（员工的 employeeId），employee_no（员工工号）】，示例值：“employee_id”
    user_flow_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 打卡流水记录 ID，示例值："6708236686834352397"


@attr.s
class GetAttendanceUserFlowRespLatitude(object):
    pass


@attr.s
class GetAttendanceUserFlowRespLongitude(object):
    pass


@attr.s
class GetAttendanceUserFlowResp(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工工号
    creator_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡记录创建者的 employee_no
    location_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡位置名称信息
    check_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 打卡时间，精确到秒的时间戳
    comment: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡备注
    record_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡记录 ID
    longitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡经度
    latitude: float = attr.ib(default=None, metadata={"req_type": "json"})  # 打卡纬度
    ssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 SSID
    bssid: str = attr.ib(default="", metadata={"req_type": "json"})  # 打卡 Wi-Fi 的 MAC 地址
    is_field: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为外勤打卡
    is_wifi: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为 Wi-Fi 打卡
    type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 记录生成方式，可用值：【0（用户自己打卡），1（管理员修改），2（用户补卡），3（系统自动生成），4（下班免打卡），5（考勤机打卡），6（极速打卡），7（考勤开放平台导入），8（飞书自研考勤机），9（飞书门禁考勤机）】
    photo_urls: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 打卡照片列表
    device_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 手机打卡设备ID


def _gen_get_attendance_user_flow_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceUserFlowResp,
        scope="Attendance",
        api="GetAttendanceUserFlow",
        method="GET",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_flows/:user_flow_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_hire_job_get import (
    GetHireJobReq,
    GetHireJobResp,
    _gen_get_hire_job_req,
)
from pylark.api_service_hire_job_manager_get import (
    GetHireJobManagerReq,
    GetHireJobManagerResp,
    _gen_get_hire_job_manager_req,
)
from pylark.api_service_hire_talent_get import (
    GetHireTalentReq,
    GetHireTalentResp,
    _gen_get_hire_talent_req,
)
from pylark.api_service_hire_attachment_get import (
    GetHireAttachmentReq,
    GetHireAttachmentResp,
    _gen_get_hire_attachment_req,
)
from pylark.api_service_hire_attachment_preview_get import (
    GetHireAttachmentPreviewReq,
    GetHireAttachmentPreviewResp,
    _gen_get_hire_attachment_preview_req,
)
from pylark.api_service_hire_resume_sources_get import (
    GetHireResumeSourceReq,
    GetHireResumeSourceResp,
    _gen_get_hire_resume_source_req,
)
from pylark.api_service_hire_note_create import (
    CreateHireNoteReq,
    CreateHireNoteResp,
    _gen_create_hire_note_req,
)
from pylark.api_service_hire_note_update import (
    UpdateHireNoteReq,
    UpdateHireNoteResp,
    _gen_update_hire_note_req,
)
from pylark.api_service_hire_note_get import (
    GetHireNoteReq,
    GetHireNoteResp,
    _gen_get_hire_note_req,
)
from pylark.api_service_hire_note_list import (
    GetHireNoteListReq,
    GetHireNoteListResp,
    _gen_get_hire_note_list_req,
)
from pylark.api_service_hire_referral_get_by_application import (
    GetHireReferralByApplicationReq,
    GetHireReferralByApplicationResp,
    _gen_get_hire_referral_by_application_req,
)
from pylark.api_service_hire_job_process_list import (
    GetHireJobProcessListReq,
    GetHireJobProcessListResp,
    _gen_get_hire_job_process_list_req,
)
from pylark.api_service_hire_application_create import (
    CreateHireApplicationReq,
    CreateHireApplicationResp,
    _gen_create_hire_application_req,
)
from pylark.api_service_hire_application_terminate import (
    TerminateHireApplicationReq,
    TerminateHireApplicationResp,
    _gen_terminate_hire_application_req,
)
from pylark.api_service_hire_application_get import (
    GetHireApplicationReq,
    GetHireApplicationResp,
    _gen_get_hire_application_req,
)
from pylark.api_service_hire_application_list import (
    GetHireApplicationListReq,
    GetHireApplicationListResp,
    _gen_get_hire_application_list_req,
)
from pylark.api_service_hire_application_interview_list import (
    GetHireApplicationInterviewListReq,
    GetHireApplicationInterviewListResp,
    _gen_get_hire_application_interview_list_req,
)
from pylark.api_service_hire_offer_get_by_application import (
    GetHireOfferByApplicationReq,
    GetHireOfferByApplicationResp,
    _gen_get_hire_offer_by_application_req,
)
from pylark.api_service_hire_offer_schema_get import (
    GetHireOfferSchemaReq,
    GetHireOfferSchemaResp,
    _gen_get_hire_offer_schema_req,
)
from pylark.api_service_hire_transfer_onboard_by_application import (
    MakeHireTransferOnboardByApplicationReq,
    MakeHireTransferOnboardByApplicationResp,
    _gen_make_hire_transfer_onboard_by_application_req,
)
from pylark.api_service_hire_employee_update import (
    UpdateHireEmployeeReq,
    UpdateHireEmployeeResp,
    _gen_update_hire_employee_req,
)
from pylark.api_service_hire_employee_get_by_application import (
    GetHireEmployeeByApplicationReq,
    GetHireEmployeeByApplicationResp,
    _gen_get_hire_employee_by_application_req,
)
from pylark.api_service_hire_employee_get import (
    GetHireEmployeeReq,
    GetHireEmployeeResp,
    _gen_get_hire_employee_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkHireService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_hire_job(
        self, request: GetHireJobReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireJobResp, Response]:
        return self.cli.raw_request(_gen_get_hire_job_req(request, options))

    def get_hire_job_manager(
        self, request: GetHireJobManagerReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireJobManagerResp, Response]:
        return self.cli.raw_request(_gen_get_hire_job_manager_req(request, options))

    def get_hire_talent(
        self, request: GetHireTalentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireTalentResp, Response]:
        return self.cli.raw_request(_gen_get_hire_talent_req(request, options))

    def get_hire_attachment(
        self, request: GetHireAttachmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireAttachmentResp, Response]:
        return self.cli.raw_request(_gen_get_hire_attachment_req(request, options))

    def get_hire_attachment_preview(
        self, request: GetHireAttachmentPreviewReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireAttachmentPreviewResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_attachment_preview_req(request, options)
        )

    def get_hire_resume_source(
        self, request: GetHireResumeSourceReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireResumeSourceResp, Response]:
        return self.cli.raw_request(_gen_get_hire_resume_source_req(request, options))

    def create_hire_note(
        self, request: CreateHireNoteReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHireNoteResp, Response]:
        return self.cli.raw_request(_gen_create_hire_note_req(request, options))

    def update_hire_note(
        self, request: UpdateHireNoteReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHireNoteResp, Response]:
        return self.cli.raw_request(_gen_update_hire_note_req(request, options))

    def get_hire_note(
        self, request: GetHireNoteReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireNoteResp, Response]:
        return self.cli.raw_request(_gen_get_hire_note_req(request, options))

    def get_hire_note_list(
        self, request: GetHireNoteListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireNoteListResp, Response]:
        return self.cli.raw_request(_gen_get_hire_note_list_req(request, options))

    def get_hire_referral_by_application(
        self, request: GetHireReferralByApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireReferralByApplicationResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_referral_by_application_req(request, options)
        )

    def get_hire_job_process_list(
        self, request: GetHireJobProcessListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireJobProcessListResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_job_process_list_req(request, options)
        )

    def create_hire_application(
        self, request: CreateHireApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHireApplicationResp, Response]:
        return self.cli.raw_request(_gen_create_hire_application_req(request, options))

    def terminate_hire_application(
        self, request: TerminateHireApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[TerminateHireApplicationResp, Response]:
        return self.cli.raw_request(
            _gen_terminate_hire_application_req(request, options)
        )

    def get_hire_application(
        self, request: GetHireApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireApplicationResp, Response]:
        return self.cli.raw_request(_gen_get_hire_application_req(request, options))

    def get_hire_application_list(
        self, request: GetHireApplicationListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireApplicationListResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_application_list_req(request, options)
        )

    def get_hire_application_interview_list(
        self,
        request: GetHireApplicationInterviewListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetHireApplicationInterviewListResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_application_interview_list_req(request, options)
        )

    def get_hire_offer_by_application(
        self, request: GetHireOfferByApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireOfferByApplicationResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_offer_by_application_req(request, options)
        )

    def get_hire_offer_schema(
        self, request: GetHireOfferSchemaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireOfferSchemaResp, Response]:
        return self.cli.raw_request(_gen_get_hire_offer_schema_req(request, options))

    def make_hire_transfer_onboard_by_application(
        self,
        request: MakeHireTransferOnboardByApplicationReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[MakeHireTransferOnboardByApplicationResp, Response]:
        return self.cli.raw_request(
            _gen_make_hire_transfer_onboard_by_application_req(request, options)
        )

    def update_hire_employee(
        self, request: UpdateHireEmployeeReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHireEmployeeResp, Response]:
        return self.cli.raw_request(_gen_update_hire_employee_req(request, options))

    def get_hire_employee_by_application(
        self, request: GetHireEmployeeByApplicationReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireEmployeeByApplicationResp, Response]:
        return self.cli.raw_request(
            _gen_get_hire_employee_by_application_req(request, options)
        )

    def get_hire_employee(
        self, request: GetHireEmployeeReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHireEmployeeResp, Response]:
        return self.cli.raw_request(_gen_get_hire_employee_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SearchApprovalInstanceReq(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 id
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 code
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 code
    instance_external_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例第三方 id <br>注：和 approval_code 取并集
    group_external_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批定义分组第三方 id <br>注：和 instance_code 取并集
    instance_title: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例标题（只有第三方审批有）
    instance_status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例状态<br>REJECT：拒绝<br>PENDING：审批中<br>RECALL：撤回<br>DELETED： 已删除<br>APPROVED：通过<br>注：若不设置，查询全部状态<br>若不在集合中，报错
    instance_start_time_from: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实例查询开始时间（unix毫秒时间戳）
    instance_start_time_to: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实例查询结束时间  (unix毫秒时间戳)
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 地区 （zh-CN、en-US、ja-JP）
    offset: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 查询偏移量 <br>注：不得超过10000
    limit: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 查询限制量 <br>注：不得超过200<br>不设置默认查询10条数据


@attr.s
class SearchApprovalInstanceRespInstanceInstanceLink(object):
    pc_link: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 pc 端链接
    mobile_link: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例移动端链接


@attr.s
class SearchApprovalInstanceRespInstanceInstance(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 code
    external_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例外部 id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例发起人 id
    start_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 审批实例开始时间
    end_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 审批实例结束时间
    status: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例状态
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例名称（只有第三方审批有）
    extra: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例扩展字段
    serial_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批流水号
    link: SearchApprovalInstanceRespInstanceInstanceLink = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 审批实例链接（只有第三方审批有）


@attr.s
class SearchApprovalInstanceRespInstanceApprovalGroup(object):
    external_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义分组外部 id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义分组名称


@attr.s
class SearchApprovalInstanceRespInstanceApprovalExternal(object):
    batch_cc_read: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否支持批量读


@attr.s
class SearchApprovalInstanceRespInstanceApproval(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 code
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义名称
    is_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为第三方审批
    external: SearchApprovalInstanceRespInstanceApprovalExternal = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 第三方审批信息
    group: SearchApprovalInstanceRespInstanceApprovalGroup = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 审批定义分组


@attr.s
class SearchApprovalInstanceRespInstance(object):
    approval: SearchApprovalInstanceRespInstanceApproval = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 审批定义
    instance: SearchApprovalInstanceRespInstanceInstance = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 审批实例信息


@attr.s
class SearchApprovalInstanceResp(object):
    count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 查询返回条数
    instance_list: typing.List[SearchApprovalInstanceRespInstance] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 审批实例列表


def _gen_search_approval_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SearchApprovalInstanceResp,
        scope="Approval",
        api="SearchApprovalInstance",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/search",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSheetMetaReqUserIDType(object):
    pass


@attr.s
class GetSheetMetaReq(object):
    ext_fields: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 额外返回的字段，extFields=protectedRange时返回保护行列信息
    user_id_type: GetSheetMetaReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 返回的用户id类型，可选open_id,union_id
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token；获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class GetSheetMetaRespSheetBlockInfo(object):
    block_token: str = attr.ib(default="", metadata={"req_type": "json"})  # block的token
    block_type: str = attr.ib(default="", metadata={"req_type": "json"})  # block的类型


@attr.s
class GetSheetMetaRespSheetProtectedRangeDimension(object):
    start_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列的起始位置，位置从1开始
    end_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 保护行列的结束位置，位置从1开始
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 若为ROWS，则为保护行；为COLUMNS，则为保护列
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围所在工作表 ID


@attr.s
class GetSheetMetaRespSheetProtectedRange(object):
    dimension: GetSheetMetaRespSheetProtectedRangeDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 保护行列的信息，如果为保护工作表，则该字段为空
    protect_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护范围ID
    lock_info: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护说明
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 保护工作表 ID


@attr.s
class GetSheetMetaRespSheetMerge(object):
    start_row_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 合并单元格范围的开始行下标，index 从 0 开始
    start_column_index: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 合并单元格范围的开始列下标，index 从 0 开始
    row_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 合并单元格范围的行数量
    column_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 合并单元格范围的列数量


@attr.s
class GetSheetMetaRespSheet(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet 的 id
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet 的标题
    index: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的位置
    row_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的最大行数
    column_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的最大列数
    frozen_row_count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 该 sheet 的冻结行数，小于等于 sheet 的最大行数，0表示未设置冻结
    frozen_col_count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 该 sheet 的冻结列数，小于等于 sheet 的最大列数，0表示未设置冻结
    merges: typing.List[GetSheetMetaRespSheetMerge] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 该 sheet 中合并单元格的范围
    protected_range: GetSheetMetaRespSheetProtectedRange = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 该 sheet 中保护范围
    block_info: GetSheetMetaRespSheetBlockInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 若含有该字段，则此工作表不为表格


@attr.s
class GetSheetMetaRespProperties(object):
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # spreadsheet 的标题
    owner_user: int = attr.ib(default=0, metadata={"req_type": "json"})  # 所有者的 id
    owner_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 所有者的 id，取决于user_id_type的值
    sheet_count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # spreadsheet 下的 sheet 数
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 该 sheet 的版本


@attr.s
class GetSheetMetaResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    properties: GetSheetMetaRespProperties = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # spreadsheet 的属性
    sheets: typing.List[GetSheetMetaRespSheet] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # spreadsheet 下的sheet列表


def _gen_get_sheet_meta_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSheetMetaResp,
        scope="Drive",
        api="GetSheetMeta",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/metainfo",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )
